DropDownUiState class

Annotations
  • @freezed

Constructors

const
factory

Properties

copyWith → $DropDownUiStateCopyWith<DropDownUiState>
Create a copy of DropDownUiState with the given fields replaced by the non-null parameter values.
no setterinherited
enabled → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
label → String
no setterinherited
placeHolder → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedText → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited